pub struct ContractFace {
pub space: String,
pub class: String,
pub dir: String,
pub opening: Region,
}Expand description
One face of the piece’s face contract.
Fields
space: StringThe space the way in or out belongs to.
class: StringThe edge’s class: walk | stair | climb | drop | barred | vision.
dir: StringWhich side of the piece: east | west | up | down | south |
north.
opening: RegionThe opening, as an inclusive local cell range flat in the face’s own axis.